SyncComponent

Trait SyncComponent 

pub trait SyncComponent<F = ()>: Component {
    type Target: Bundle
       where <Self::Target as DynamicBundle>::Effect: NoBundleEffect;
}
Trait that links components from the main world with output components in the render world. It is used by SyncComponentPlugin.

The marker type F is only used as a way to bypass the orphan rules. To implement the trait for a foreign type you can use a local type as the marker, e.g. the type of the plugin that calls SyncComponentPlugin.

Required Associated Types

type Target: Bundle where <Self::Target as DynamicBundle>::Effect: NoBundleEffect

Describes what components should be removed from the render world if the implementing component is removed.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl SyncComponent for AtmosphereSettings

Source

impl SyncComponent for AutoExposure

Source

impl SyncComponent for Bloom

Source

type Target = (Bloom, BloomUniforms)

Source

impl SyncComponent for Camera2d

Source

impl SyncComponent for Camera3d

Source

impl SyncComponent for CameraMainTextureUsages

Source

impl SyncComponent for ChromaticAberration

Source

impl SyncComponent for ContactShadows

Source

impl SyncComponent for DebandDither

Source

impl SyncComponent for DepthOfField

Source

impl SyncComponent for DistanceFog

Source

impl SyncComponent for LensDistortion

Source

impl SyncComponent for MotionBlur

Source

type Target = MotionBlurUniform

Source

impl SyncComponent for Msaa
where Msaa: Clone,

Source

impl SyncComponent for NoBackgroundMotionVectors

Source

impl SyncComponent for OcclusionCulling

Source

impl SyncComponent for OrderIndependentTransparencySettings

Source

impl SyncComponent for PbrDeferredLightingDepthId

Source

impl SyncComponent for Readback
where Readback: Clone,

Source

impl SyncComponent for ScreenSpaceAmbientOcclusion

Source

impl SyncComponent for ScreenSpaceReflections

Source

impl SyncComponent for ScreenSpaceTransmission

Source

impl SyncComponent for Tonemapping

Source

impl SyncComponent for Vignette

Source

impl SyncComponent<ClusteredDecalPlugin> for ClusteredDecal

Source

impl SyncComponent<EnvironmentMapGenerationPlugin> for GeneratedEnvironmentMapLight

Source

impl SyncComponent<PbrPlugin> for AmbientLight

Source

impl SyncComponent<PbrPlugin> for DirectionalLight

Source

impl SyncComponent<PbrPlugin> for PointLight

Source

impl SyncComponent<PbrPlugin> for RectLight

Source

impl SyncComponent<PbrPlugin> for ShadowFilteringMethod

Source

impl SyncComponent<PbrPlugin> for SpotLight

Source

impl SyncComponent<SkyboxPlugin> for Skybox

Source

impl SyncComponent<VolumetricFogPlugin> for FogVolume